@@ -12,7 +12,7 @@ int		factor_cmd(), derivative_cmd(), replace_cmd(), approximate_cmd();
 int		save_cmd(), taylor_cmd(), limit_cmd(), echo_cmd(), plot_cmd();
 int		copy_cmd(), divide_cmd(), pause_cmd(), version_cmd();
 int		edit_cmd(), real_cmd(), imaginary_cmd(), tally_cmd();
-int		roots_cmd(), set_cmd(), variables_cmd(), code_cmd(), optimize_cmd(), push_cmd();
+int		roots_cmd(), set_cmd(), variables_cmd(), code_cmd(), optimize_cmd(), push_cmd(), push_en();
 int		sum_cmd(), product_cmd(), for_cmd(), integrate_cmd(), nintegrate_cmd(), laplace_cmd();
 
 /* various functions that don't return int */
