@@ -326,8 +326,7 @@ check_gvars(void)
 	partial_flag == true &&
 	symb_flag == false &&
 	sign_cmp_flag == false &&
-	approximate_roots == false &&
-	repeat_flag == false))
+	approximate_roots == false))
 		error_bug("Global vars got changed!");
 
 	if (!(zero_token.level == 1 &&
