@@ -43,7 +43,6 @@ George Gesslein II, P.O. Box 224, Lansing, NY  14882-0224  USA.
 
 #define	MAX_K_INTEGER	1.0e15		/* maximum safely representable floating point integer, 15 digits for doubles */
 
-#define	blt(dst, src, cnt)	memmove((char *) (dst), (char *) (src), (size_t) (cnt))	/* memory copy function; must allow overlapping of src and dst */
 #define always_positive(power)	(fmod((double) (power), 2.0) == 0.0)	/* true if all real numbers raised to "power" result in positive, real numbers */
 
 #if	I18N		/* Internationalization: allow output in languages other than English using gettext(3). */
@@ -63,8 +62,10 @@ George Gesslein II, P.O. Box 224, Lansing, NY  14882-0224  USA.
 #define	PROMPT_STR	"-> "				/* user interface main prompt strings, preceded by the current equation number */
 #define	HTML_PROMPT_STR	"&minus;&gt; "			/* main prompt in HTML output mode, should be same number of columns as above */
 
-#define	MAX_CMD_LEN	min((max(PATH_MAX, 1024)), 16384)	/* maximum command line length (not expression input), also max filename length */
-#define	MAX_PROMPT_LEN	STANDARD_SCREEN_COLUMNS		/* maximum length of prompts */
+#define	MAX_CMD_LEN	min((max(PATH_MAX, 1024)), 16384)	/* Maximum Mathomatic main prompt command-line length */
+								/* (not expression input, which can be much larger); */
+								/* also max filename length. */
+#define	MAX_PROMPT_LEN	STANDARD_SCREEN_COLUMNS		/* maximum length of prompts, limited to fit on normal terminals */
 
 /*
  * What follows is the definition of each array element in a mathematical expression,
@@ -127,7 +128,7 @@ typedef	struct {		/* storage structure for each token in an expression */
  */
 #ifndef	DEFAULT_N_TOKENS
 #if	HANDHELD
-#define	DEFAULT_N_TOKENS	6000
+#define	DEFAULT_N_TOKENS	10000
 #else
 #define	DEFAULT_N_TOKENS	60000
 #endif
@@ -169,14 +170,32 @@ enum language_list {
 
 /* Debugging macros: */
 #if	SILENT
-#define	list_tdebug(level)		{ ; }
-#define	side_debug(level, p1, n1)	{ ; }
-#define debug_string(level, str)	{ ; }
+#define	list_esdebug(level, en)		{ ; }	/* Display an equation space. */
+#define	list_tdebug(level)		{ ; }	/* Display the temporary equation (e.g.: when solving). */
+#define	side_debug(level, p1, n1)	{ ; }	/* Display any expression. */
+#define debug_string(level, str)	{ ; }	/* Display any ASCII string. */
 #else
+#define	list_esdebug(level, en)		list_debug(level, lhs[en], n_lhs[en], rhs[en], n_rhs[en])
 #define list_tdebug(level)		list_debug(level, tlhs, n_tlhs, trhs, n_trhs)
 #define	side_debug(level, p1, n1)	list_debug(level, p1, n1, NULL, 0)
 #define debug_string(level, str)	{ if (debug_level >= (level)) fprintf(gfp, "%s\n", str); }
 #endif
 
-/* The correct way to determine if equation number "en" is not in use. */
-#define empty_equation_space(en)	((en) < 0 || (en) >= n_equations || n_lhs[en] <= 0)
+/* The correct ways to determine if equation number "en" (origin 0) contains an expression or equation. */
+#define empty_equation_space(en)	((en) < 0 || (en) >= n_equations || n_lhs[(en)] <= 0)
+#define	equation_space_is_equation(en)	((en) >= 0 && (en) < n_equations && n_lhs[(en)] > 0 && n_rhs[(en)] > 0)
+
+/*
+ * The following are macros for displaying help text.
+ * When used properly, they will allow nicer looking wrap-around on all help text.
+ * If NOT80COLUMNS is 1, paragraphs will all be one long line.
+ * This is helpful when the output device has less than 80 text character columns.
+ */
+#if	NOT80COLUMNS
+#define SP(str)	fprintf(gfp, "%s ", str)	/* display part of a paragraph, separated with spaces (Space Paragraph) */
+#define EP(str)	fprintf(gfp, "%s\n", str)	/* display the end of a paragraph (End Paragraph) */
+#else	/* Otherwise the following only works nicely with 80 column or wider screens; */
+	/* all strings passed to it should be less than 80 columns if possible, so it doesn't wrap around. */
+#define SP(str)	fprintf(gfp, "%s\n", str)
+#define EP(str)	fprintf(gfp, "%s\n", str)
+#endif
