@@ -61,23 +61,23 @@ do_repeat:
 			return false;
 	}
 	root = strtod(cp, &cp);
-	if ((*cp && !isspace(*cp)) || root < 0.0 || root > MAX_ROOT || fmod(root, 1.0) != 0.0) {
+	if ((*cp && *cp != ',' && !isspace(*cp)) || !isfinite(root) || root < 0.0 || root > MAX_ROOT || fmod(root, 1.0) != 0.0) {
 		error(_("Root invalid or out of range."));
 		printf(_("Root must be a positive integer less than or equal to %.0f.\n"), MAX_ROOT);
 		return false;
 	}
-	cp = skip_space(cp);
+	cp = skip_comma_space(cp);
 	if (*cp == '\0') {
 		my_strlcpy(prompt_str, _("Enter real part (X): "), sizeof(prompt_str));
 		if ((cp = get_string(buf, sizeof(buf))) == NULL)
 			return false;
 	}
 	c.re = strtod(cp, &cp);
-	if (*cp && !isspace(*cp)) {
+	if (*cp && *cp != ',' && !isspace(*cp)) {
 		error(_("Number expected."));
 		return false;
 	}
-	cp = skip_space(cp);
+	cp = skip_comma_space(cp);
 	if (*cp == '\0') {
 		my_strlcpy(prompt_str, _("Enter imaginary part (Y): "), sizeof(prompt_str));
 		if ((cp = get_string(buf, sizeof(buf))) == NULL)
@@ -98,7 +98,7 @@ do_repeat:
 		radius_root = pow(radius, 1.0 / root);
 	}
 	check_err();
-	fprintf(gfp, _("\nThe polar coordinates are:\n%.*g amplitude and %.*g radians (%.*g degrees).\n\n"),
+	fprintf(gfp, _("\nThe polar coordinates are:\n%.*g amplitude and\n%.*g radians (%.*g degrees).\n\n"),
 	    precision, radius, precision, theta, precision, theta * 180.0 / M_PI);
 	if (root) {
 		if (c.im == 0.0) {
@@ -119,7 +119,7 @@ do_repeat:
 			}
 			fprintf(gfp, "\n");
 #if	!SILENT
-			if (debug_level < 0) {
+			if (debug_level <= 0) {
 				continue;
 			}
 			check = c2;
@@ -189,8 +189,10 @@ start_over:
 		if (*np + 5 - (i - j) > n_tokens) {
 			error_huge();
 		}
-		blt(&equation[j+5], &equation[i], (*np - i) * sizeof(token_type));
-		*np += 5 - (i - j);
+		if ((j + 5) != i) {
+			blt(&equation[j+5], &equation[i], (*np - i) * sizeof(token_type));
+			*np += 5 - (i - j);
+		}
 		equation[j].level = level;
 		equation[j].kind = CONSTANT;
 		equation[j].token.constant = r.re;
