@@ -360,37 +360,38 @@ char	*cp;
 		if (extra_characters(cp))
 			return false;
 	}
-	show_usage = false;
 	if (no_vars(source, *nps, &v)) {
 		warning(_("Current expression contains no variables; the derivative will be zero."));
-	} else if (v == 0) {
-		if (!prompt_var(&v)) {
-			return false;
+	} else {
+		if (v == 0) {
+			if (!prompt_var(&v)) {
+				return false;
+			}
+		}
+		if (v && v != MATCH_ANY && !found_var(source, *nps, v)) {
+			warning(_("Specified variable not found; the derivative will be zero."));
 		}
 	}
 	if (v == 0) {
 		error(_("No differentiation variable specified."));
 		return false;
 	}
-	if (v != MATCH_ANY && !found_var(source, *nps, v)) {
-		warning(_("Specified variable not found; the derivative will be zero."));
-	}
 #if	!SILENT
-	if (debug_level >= 0) {
-		list_var(v, 0);
-		if (n_rhs[cur_equation]) {
-			fprintf(gfp, _("Differentiating the RHS with respect to (%s)"), var_str);
-		} else {
-			fprintf(gfp, _("Differentiating with respect to (%s)"), var_str);
-		}
-		if (order != 1) {
-			fprintf(gfp, _(" %ld times"), order);
-		}
-		if (simplify_flag) {
-			fprintf(gfp, _(" and simplifying"));
-		}
-		fprintf(gfp, "...\n");
+	list_var(v, 0);
+	if (n_rhs[cur_equation]) {
+		fprintf(gfp, _("Differentiating the RHS with respect to %s"), var_str);
+	} else {
+		fprintf(gfp, _("Differentiating with respect to %s"), var_str);
 	}
+	if (order != 1) {
+		fprintf(gfp, _(" %ld times"), order);
+	}
+	if (simplify_flag) {
+		fprintf(gfp, _(" and simplifying"));
+	} else {
+		fprintf(gfp, _(" and not simplifying"));
+	}
+	fprintf(gfp, "...\n");
 #endif
 	blt(dest, source, *nps * sizeof(token_type));
 	n1 = *nps;
@@ -534,7 +535,7 @@ char	*cp;
 	int		level;
 	long		l1, n, order = -1L;
 	double		d;
-	char		*cp_start, *cp1, buf[MAX_CMD_LEN];
+	char		*cp_start, *cp1 = NULL, buf[MAX_CMD_LEN];
 	int		our;
 	int		our_nlhs, our_nrhs;
 	token_type	*ep, *source, *dest;
@@ -593,7 +594,7 @@ char	*cp;
 		}
 	}
 	if (!found_var(source, *nps, v)) {
-		warning(_("Specified variable not found."));
+		warning(_("Specified differentiation variable not found; the derivative will be 0."));
 	}
 	blt(rhs[our], source, *nps * sizeof(token_type));
 	our_nrhs = *nps;
@@ -615,7 +616,7 @@ char	*cp;
 		list_var(v, 0);
 		printf(_("Taylor series expansion around %s = point.\n"), var_str);
 #endif
-		my_strlcpy(prompt_str, _("Enter point: "), sizeof(prompt_str));
+		my_strlcpy(prompt_str, _("Enter point (an expression; usually 0): "), sizeof(prompt_str));
 		if (!get_expr(lhs[our], &our_nlhs)) {
 			return false;
 		}
@@ -625,25 +626,30 @@ char	*cp;
 		if ((cp1 = get_string(buf, sizeof(buf))) == NULL)
 			return false;
 		if (*cp1) {
+			cp = NULL;
 			order = decstrtol(cp1, &cp);
-			if (*cp || order < 0) {
+			if (cp == NULL || *cp || order < 0) {
 				error(_("Positive integer required for order."));
 				return false;
 			}
 		} else {
-			order = LONG_MAX - 1L;
+			order = LONG_MAX - 1;
 #if	!SILENT
 			printf(_("Derivatives will be taken until they reach zero...\n"));
 #endif
 		}
 	}
 #if	!SILENT
-	fprintf(gfp, _("Computing the Taylor series"));
+	fprintf(gfp, _("Taylor series"));
 	if (n_rhs[cur_equation]) {
 		fprintf(gfp, _(" of the RHS"));
 	}
+	list_var(v, 0);
+	fprintf(gfp, _(" with respect to %s"), var_str);
 	if (simplify_flag) {
-		fprintf(gfp, _(" and simplifying"));
+		fprintf(gfp, _(", simplified"));
+	} else {
+		fprintf(gfp, _(", not simplified"));
 	}
 	fprintf(gfp, "...\n");
 #endif
@@ -725,9 +731,9 @@ loop_again:
 				return false;
 			}
 		}
-		symb_flag = symblify;
+/*		symb_flag = symblify; */
 		simpa_repeat_side(rhs[our], &our_nrhs, true, false /* was true */);
-		symb_flag = false;
+/*		symb_flag = false; */
 		if (our_nrhs != 1 || rhs[our][0].kind != CONSTANT || rhs[our][0].token.constant != 0.0) {
 			i1 = n1;
 			if ((i1 + 1 + our_nrhs) > n_tokens)
@@ -745,7 +751,7 @@ loop_again:
 		}
 	}
 #if	!SILENT
-	fprintf(gfp, _("%ld derivative%s applied.\n"), n, (n == 1) ? "" : "s");
+	fprintf(gfp, _("%ld non-zero derivative%s applied.\n"), n, (n == 1) ? "" : "s");
 #endif
 	if (n_rhs[cur_equation]) {
 		n_lhs[i] = n_lhs[cur_equation];
@@ -795,8 +801,8 @@ char	*cp;
 	}
 	show_usage = false;
 	if (no_vars(rhs[cur_equation], n_rhs[cur_equation], &v)) {
-		error(_("Current expression contains no variables."));
-		return false;
+		warning(_("Current expression contains no variables; that is the answer."));
+		return return_result(cur_equation);
 	}
 	if (v == 0) {
 		if (!prompt_var(&v)) {
@@ -804,8 +810,8 @@ char	*cp;
 		}
 	}
 	if (!found_var(rhs[cur_equation], n_rhs[cur_equation], v)) {
-		error(_("Limit variable not found."));
-		return false;
+		warning(_("Limit variable not found; answer is original expression."));
+		return return_result(cur_equation);
 	}
 	if (*cp == '=') {
 		cp = skip_space(cp + 1);
@@ -819,19 +825,17 @@ char	*cp;
 		}
 	} else {
 		list_var(v, 0);
-		snprintf(prompt_str, sizeof(prompt_str), _("as (%s) goes to: "), var_str);
+		snprintf(prompt_str, sizeof(prompt_str), _("as %s goes to: "), var_str);
 		if (!get_expr(tes, &n_tes)) {
 			return false;
 		}
 	}
 	simp_loop(tes, &n_tes);
 #if	!SILENT
-	if (debug_level >= 0) {
-		list_var(v, 0);
-		fprintf(gfp, _("Taking the limit as %s goes to "), var_str);
-		list_proc(tes, n_tes, false);
-		fprintf(gfp, "\n");
-	}
+	list_var(v, 0);
+	fprintf(gfp, _("Taking the limit as %s goes to "), var_str);
+	list_proc(tes, n_tes, false);
+	fprintf(gfp, "\n");
 #endif
 /* copy the current equation to a new equation space, then simplify and work on the copy: */
 	copy_espace(cur_equation, i);
