@@ -4,7 +4,7 @@
 # that is, it returns the same type as its single argument.
 # Gives an error for negative or non-integer input values.
 
-def fact(x):
+def factorial(x):
 	"Return x! (x factorial)."
 	if (x < 0 or (x % 1.0) != 0.0):
 		raise ValueError, "Factorial argument must be a positive integer."
