@@ -48,9 +48,9 @@ typedef	struct {
  */
 static com_type com_list[] = {
 /*	command name,	alternate name,		function,		usage,							information */
-{	"approximate",	NULL,			approximate_cmd,	"[equation-number-ranges]",				"Approximate all numerical values in equation spaces." },
+{	"approximate",	NULL,			approximate_cmd,	"[equation-number-ranges]",				"Approximate all numerical values in equation spaces.", "\"repeat approximate\" approximates more, like calculate." },
 #if	!LIBRARY
-{	"calculate",	NULL,			calculate_cmd,		"[\"factor\"] [equation-number-range] [variable iterations]",	"Temporarily plug in values for variables and approximate.", "This command may be preceded with \"repeat\"." },
+{	"calculate",	NULL,			calculate_cmd,		"[\"factor\"] [equation-number-range] [variable iterations]",	"Temporarily plug in values for variables and approximate well.", "\"repeat calculate\" repeatedly prompts for any input." },
 #endif
 {	"clear",	NULL,			clear_cmd,		"[equation-number-ranges]",				"Delete expressions stored in memory so equation spaces can be reused.", "Tip: Use \"clear all\" to quickly restart Mathomatic." },
 {	"code",		NULL,			code_cmd,		"[\"c\" or \"java\" or \"python\" or \"integer\"] [equation-number-ranges]",	"Output C, Java, or Python code for the specified equations.", "Related commands: simplify, optimize, and variables" },
@@ -58,7 +58,7 @@ static com_type com_list[] = {
 {	"copy",		NULL,			copy_cmd,		"[\"select\"] [equation-number-ranges]",		"Duplicate the contents of the specified equation spaces.", "With select, the first copy is made the current equation." },
 {	"derivative",	"differentiate",	derivative_cmd,		"[\"nosimplify\"] variable or \"all\" [order]",		"Symbolically differentiate and simplify, order times." },
 {	"display",	NULL,			display_cmd,		"[\"factor\"] [\"simple\" or \"mixed\"] [equation-number-ranges]",	"Display expressions in pretty, 2D multi-line fraction format." },
-{	"divide",	NULL,			divide_cmd,		"[base-variable] [dividend divisor]",			"Divide 2 numbers or polynomials. Give detailed result and GCD.", "This command may be preceded with \"repeat\"." },
+{	"divide",	NULL,			divide_cmd,		"[base-variable] [dividend divisor]",			"Divide 2 numbers or polynomials. Give detailed result and GCD.", "\"repeat divide\" repeatedly prompts for any input." },
 {	"echo",		NULL,			echo_cmd,		"[text]",						"Output a line of text, followed by a newline.", "This command may be preceded with \"repeat\"." },
 #if	SHELL_OUT
 {	"edit",		NULL,			edit_cmd,		"[file-name]",						"Edit all equation spaces or an input file, then read them in.", "Editor name in EDITOR environment variable." },
@@ -90,11 +90,11 @@ static com_type com_list[] = {
 {	"quit",		"exit",			quit_cmd,		"[exit-value]",						"Terminate this program without saving." },
 #endif
 #if	!SECURE
-{	"read",		NULL,			read_cmd,		"[file-name or directory]",				"Display/change directory, or read in a text file as if it was typed in.", "This command may be preceded with \"repeat\"." },
+{	"read",		NULL,			read_cmd,		"[file-name or directory]",				"Display/change directory, or read in a text file as if it was typed in.", "\"repeat read\" will read in a file repeatedly until failure." },
 #endif
 {	"real",		NULL,			real_cmd,		"[variable]",						"Fully expand and copy the real part of the current expression.", "Related command: imaginary" },
 {	"replace",	NULL,			replace_cmd,		"[variables [\"with\" expression]]",			"Substitute variables in the current equation with expressions.", "This command may be preceded with \"repeat\"." },
-{	"roots",	NULL,			roots_cmd,		"root real-part imaginary-part",			"Display all the roots of a complex number.", "This command may be preceded with \"repeat\"." },
+{	"roots",	NULL,			roots_cmd,		"root real-part imaginary-part",			"Display all the roots of a complex number.", "\"repeat roots\" repeatedly prompts for any input." },
 #if	!SECURE
 {	"save",		NULL,			save_cmd,		"file-name",						"Save all equation spaces in a text file.", "Related command: read" },
 #endif
@@ -177,12 +177,13 @@ char	*geometry_strings[] = {
 	"sphere_surface_area = 4*pi*r^2\n",
 	"\n",
 	"; Convex 2D polygon with straight sides,\n",
-	"; sum of all interior angles formula in degree and radian units:\n",
+	"; sum of all interior angles formula in degree, radian, and gradian units:\n",
 	"sum_degrees = (sides - 2)*180\n",
 	"sum_radians = (sides - 2)*pi\n",
+	"sum_grads = (sides - 2)*180*10/9 ; Rarely used gradian formula.\n",
 	"; \"sides\" is the number of sides of any convex 2D polygon.\n",
 	"; Convex means that all interior angles are less than 180 degrees.\n",
-	"; Type \"eliminate sides\" to get the radians/degrees conversion formula.\n",
+	"; Type \"elim sides\" to get the radians/degrees/grads conversion formulas.\n",
 	NULL
 };
 
@@ -979,7 +980,7 @@ intro:
 #if	!LIBRARY
 		SP("Type \"help options\" for a list of shell command-line startup options.");
 #endif
-		SP("To see helpful interactive examples, type \"help examples\".");
+		SP("For helpful interactive examples, \"help examples\". For news, \"help news\".");
 		SP("Type \"help equations\" for help with entering expressions and equations.");
 		SP("Type \"help all\" for a summary of all commands or \"help usage\" just for syntax.");
 		SP("Other help topics: constants, color, license, bugs, geometry, or conversions.");
@@ -1129,6 +1130,13 @@ next_argument:
 			version_report();
 			goto next_space;
 		}
+#if	SHELL_OUT
+		if (strncasecmp(cp, "news", cp1 - cp) == 0) {
+			underline_title(EP("What's New!"));
+			shell_out("w3m http://mathomatic.org/NEWS");
+			goto next_space;
+		}
+#endif
 		if (strncasecmp(cp, "usage", cp1 - cp) == 0
                     || strncasecmp(cp, "syntax", cp1 - cp) == 0) {
 			underline_title(EP("Mathomatic Command Usage Syntax"));
