@@ -253,12 +253,15 @@ char	*cp;
 	int		n1, n2, *nps, *np;
 	int		definite_flag = false, constant_flag = false, solved;
 	double		integrate_order = 1.0;
-	char		var_name_buf[MAX_VAR_LEN];
+	char		var_name_buf[MAX_VAR_LEN], *cp_start;
 	long		l1;
 
+	cp_start = cp;
 	if (current_not_defined()) {
 		return false;
 	}
+	n_tlhs = 0;
+	n_trhs = 0;
 	solved = solved_equation(cur_equation);
 	i = next_espace();
 	for (;; cp = skip_param(cp)) {
@@ -277,6 +280,10 @@ char	*cp;
 		return false;
 	}
 	if (n_rhs[cur_equation]) {
+		if (!solved) {
+			warning(_("Not a solved equation."));
+		}
+		debug_string(0, _("Only the RHS will be transformed."));
 		source = rhs[cur_equation];
 		nps = &n_rhs[cur_equation];
 		dest = rhs[i];
@@ -297,12 +304,28 @@ char	*cp;
 		if (*cp) {
 			integrate_order = strtod(cp, &cp);
 		}
-		if (integrate_order <= 0 || fmod(integrate_order, 1.0) != 0.0) {
+		if (!isfinite(integrate_order) || integrate_order <= 0 || fmod(integrate_order, 1.0) != 0.0) {
 			error(_("The order must be a positive integer."));
 			return false;
 		}
-		if (extra_characters(cp))
+	}
+
+	if (*cp) {
+		cp = skip_comma_space(cp);
+		input_column += (cp - cp_start);
+		cp = parse_expr(tlhs, &n_tlhs, cp, false);
+		if (cp == NULL || n_tlhs <= 0) {
 			return false;
+		}
+	}
+	if (*cp) {
+		cp_start = cp;
+		cp = skip_comma_space(cp);
+		input_column += (cp - cp_start);
+		cp = parse_expr(trhs, &n_trhs, cp, false);
+		if (cp == NULL || extra_characters(cp) || n_trhs <= 0) {
+			return false;
+		}
 	}
 	show_usage = false;
 	if (v == 0) {
@@ -311,18 +334,16 @@ char	*cp;
 		}
 	}
 #if	!SILENT
-	if (debug_level >= 0) {
-		list_var(v, 0);
-		if (n_rhs[cur_equation]) {
-			fprintf(gfp, _("Integrating the RHS with respect to (%s)"), var_str);
-		} else {
-			fprintf(gfp, _("Integrating with respect to (%s)"), var_str);
-		}
-		if (integrate_order != 1.0) {
-			fprintf(gfp, _(" %.*g times"), precision, integrate_order);
-		}
-		fprintf(gfp, _(" and simplifying...\n"));
+	list_var(v, 0);
+	if (n_rhs[cur_equation]) {
+		fprintf(gfp, _("Integrating the RHS with respect to %s"), var_str);
+	} else {
+		fprintf(gfp, _("Integrating with respect to %s"), var_str);
 	}
+	if (integrate_order != 1.0) {
+		fprintf(gfp, _(" %.*g times"), precision, integrate_order);
+	}
+	fprintf(gfp, _(" and simplifying...\n"));
 #endif
 	partial_flag = false;
 	uf_simp(source, nps);
@@ -361,13 +382,17 @@ char	*cp;
 		simp_loop(dest, &n1);
 	}
 	if (definite_flag) {
-		my_strlcpy(prompt_str, _("Enter lower bound: "), sizeof(prompt_str));
-		if (!get_expr(tlhs, &n_tlhs)) {
-			return false;
+		if (n_tlhs == 0) {
+			my_strlcpy(prompt_str, _("Enter lower bound: "), sizeof(prompt_str));
+			if (!get_expr(tlhs, &n_tlhs)) {
+				return false;
+			}
 		}
-		my_strlcpy(prompt_str, _("Enter upper bound: "), sizeof(prompt_str));
-		if (!get_expr(trhs, &n_trhs)) {
-			return false;
+		if (n_trhs == 0) {
+			my_strlcpy(prompt_str, _("Enter upper bound: "), sizeof(prompt_str));
+			if (!get_expr(trhs, &n_trhs)) {
+				return false;
+			}
 		}
 		blt(scratch, dest, n1 * sizeof(token_type));
 		n2 = n1;
@@ -569,15 +594,22 @@ char	*cp;
 {
 	int		i;
 	long		v = 0;
-	int		inverse_flag;
+	int		inverse_flag, solved;
 	token_type	*source, *dest;
 	int		n1, *nps, *np;
 
 	if (current_not_defined()) {
 		return false;
 	}
+	solved = solved_equation(cur_equation);
 	i = next_espace();
 	if (n_rhs[cur_equation]) {
+		if (!solved) {
+			warning(_("Not a solved equation."));
+		}
+#if	!SILENT
+		fprintf(gfp, _("Only the RHS will be transformed.\n"));
+#endif
 		source = rhs[cur_equation];
 		nps = &n_rhs[cur_equation];
 		dest = rhs[i];
@@ -665,6 +697,9 @@ char	*cp;
 	solved = solved_equation(cur_equation);
 	i = next_espace();
 	if (n_rhs[cur_equation]) {
+		if (!solved) {
+			warning(_("Not a solved equation."));
+		}
 		source = rhs[cur_equation];
 		nps = &n_rhs[cur_equation];
 		dest = rhs[i];
@@ -701,7 +736,7 @@ char	*cp;
 	}
 	if (*cp) {
 		cp_start = cp;
-		cp = skip_space(cp);
+		cp = skip_comma_space(cp);
 		input_column += (cp - cp_start);
 		cp = parse_expr(trhs, &n_trhs, cp, false);
 		if (cp == NULL || extra_characters(cp) || n_trhs <= 0) {
@@ -715,13 +750,11 @@ char	*cp;
 		}
 	}
 #if	!SILENT
-	if (debug_level >= 0) {
-		list_var(v, 0);
-		if (n_rhs[cur_equation]) {
-			fprintf(gfp, _("Numerically integrating the RHS wrt (%s)...\n"), var_str);
-		} else {
-			fprintf(gfp, _("Numerically integrating wrt (%s)...\n"), var_str);
-		}
+	list_var(v, 0);
+	if (n_rhs[cur_equation]) {
+		fprintf(gfp, _("Numerically integrating the RHS with respect to %s...\n"), var_str);
+	} else {
+		fprintf(gfp, _("Numerically integrating with respect to %s...\n"), var_str);
 	}
 #endif
 	singularity = false;
