@@ -25,8 +25,8 @@ main()
         printf("Not enough memory.\n");
         exit(1);
     }
-    matho_parse("x^2=4", NULL);
-    rv = matho_process("solve x", &output);
+    matho_parse((char *) "x^2=4", NULL);
+    rv = matho_process((char *) "solve x", &output);
     if (output) {
         printf("%s\n", output);
         if (rv) {
