@@ -1,12 +1,12 @@
 /*
- * Mathomatic API
+ * Mathomatic API, Copyright (C) 1996-2012 George Gesslein II.
  *
  * This file contains the required C functions and simple interface
  * for developers to use the Mathomatic symbolic math library properly.
  * These functions are included in the library.
  * Refer to this, if you are going to use the Mathomatic code in other projects.
  *
- * Be sure to call clear_all() to erase all equation spaces
+ * Be sure to call matho_clear(3) to erase all equation spaces
  * after completing each group of operations,
  * otherwise the equation spaces will fill up.
  */
@@ -37,13 +37,34 @@ matho_init(void)
 	return true;
 }
 
+/** 3
+ * matho_clear - Erase all equation spaces so they can be reused
+ * Mathomatic only has a limited number of equation spaces.
+ * Similar to a restart, recommended after each group of symbolic math operations.
+ * Currently this is the same as entering the command "clear all".
+ *
+ * matho_init(3) must have been called only one time before this
+ * to initialize the Mathomatic symbolic math engine.
+ */
+void
+matho_clear(void)
+{
+	clear_all();
+}
+
 /** 3
  * matho_process - Process Mathomatic command or expression input
  * Process a Mathomatic command or enter an expression into an equation space.
  * The command or expression ASCII string is given as "input",
  * the resulting output string is stored in "*outputp".
  *
+ * matho_init(3) must have been called only one time before this
+ * to initialize the Mathomatic symbolic math engine.
+ * Use matho_clear(3) as many times as you want to restart Mathomatic
+ * for the next group of operations.
+ *
  * This function works just like typing something into the Mathomatic prompt.
+ * To only parse any expression or equation and store it, use matho-parse(3).
  *
  * If this returns true (non-zero), the command or input was successful,
  * and the resulting expression output string is stored in "*outputp".
@@ -92,6 +113,7 @@ matho_process(char *input, char **outputp)
 		}
 		free_result_str();
 		free(input);
+		previous_return_value = 0;
 		return false;
 	}
 	set_error_level(input);
@@ -125,6 +147,11 @@ matho_process(char *input, char **outputp)
  * making it the current equation.
  * Afterwards, it can be operated on by Mathomatic commands using matho_process(3).
  *
+ * matho_init(3) must have been called only one time before this
+ * to initialize the Mathomatic symbolic math engine.
+ * Use matho_clear(3) as many times as you want to restart Mathomatic
+ * for the next group of operations.
+ *
  * The input and output ASCII strings are expressions, if successful.
  * The expression or equation string to enter is in "input",
  * the resulting output string is stored in "*outputp".
@@ -134,6 +161,8 @@ matho_process(char *input, char **outputp)
  *
  * Works the same as matho_process(3), except commands are not allowed,
  * so that variables are not ever confused with commands.
+ * In fact, this function is currently set to only allow
+ * entry and storage of expressions and equations.
  *
  * Returns true (non-zero) if successful.
  */
@@ -170,10 +199,10 @@ matho_parse(char *input, char **outputp)
 	}
 	set_error_level(input);
 	i = next_espace();
-#if	1	/* set this true if you want to be able to enter single variable expressions with no solving */
-	rv = parse(i, input);
+#if	1	/* Leave this as 1 if you want to be able to enter single variable or constant expressions with no solving or selecting. */
+	rv = parse(i, input);	/* All set auto options ignored. */
 #else
-	rv = process_parse(i, input);
+	rv = process_parse(i, input);	/* All set auto options respected. */
 #endif
 	if (rv) {
 		if (outputp) {
