@@ -30,7 +30,7 @@ char	*license_string =
 "with no Invariant Sections, no Front-Cover Texts, and no Back-Cover Texts,\n"
 "so it can be easily published, corrected, and translated by anyone.\n\n"
 
-"Chief author, maintainer, and copyright holder contact information:\n\n"
+"Chief author and copyright holder contact information:\n\n"
 
 "  email:\n"
 "    gesslein@mathomatic.org or\n"
@@ -42,4 +42,9 @@ char	*license_string =
 "    Lansing, New York  14882-0224\n"
 "    USA\n\n"
 
-"Others who have contributed code to Mathomatic are listed in file \"AUTHORS\".\n";
+"Most others who have kindly contributed working code or good ideas to\n"
+"Mathomatic are listed in the files \"AUTHORS\" and \"changes.txt\".\n"
+"Great merit is given to people that report bugs, in the file \"changes.txt\".\n"
+"This means you will also show up in the file \"NEWS\".\n"
+"To report a bug, simply email the author, or use the bug reporting facility\n"
+"shown with \"help bugs\".\n";
