@@ -1110,7 +1110,7 @@ int	n;	/* equation space number */
 
 	if (empty_equation_space(n))
 		return 0;
-#if	ROBOT_COMMAND
+#if	1	/* always respect "set columns" */
 	use_screen_columns = true;
 #else
 	use_screen_columns = (gfp == stdout);
