@@ -91,21 +91,21 @@ FILE	*fp;
 	fprintf(fp, _("Mathomatic computer algebra system, version %s\n"), VERSION);
 	fprintf(fp, _("Usage: %s [ options ] [ input_files or input ]\n\n"), prog_name);
 	fprintf(fp, _("Options:\n"));
-	fprintf(fp, _("  -a            Enable alternative color mode.\n"));
-	fprintf(fp, _("  -b            Enable bold color mode.\n"));
-	fprintf(fp, _("  -c            Toggle color mode.\n"));
-	fprintf(fp, _("  -d            Set demo mode.\n"));
-	fprintf(fp, _("  -e            Process expressions and commands on the command line.\n"));
-	fprintf(fp, _("  -h            Display this help and exit.\n"));
-	fprintf(fp, _("  -m number     Specify a memory size multiplier.\n"));
-	fprintf(fp, _("  -q            Set quiet mode (don't display prompts).\n"));
-	fprintf(fp, _("  -r            Disable readline.\n"));
-	fprintf(fp, _("  -s level      Set enforced security level for session.\n"));
-	fprintf(fp, _("  -t            Set test mode.\n"));
-	fprintf(fp, _("  -u            Set unbuffered output with input echo.\n"));
-	fprintf(fp, _("  -v            Display version number, then exit successfully.\n"));
-	fprintf(fp, _("  -w            Wide output mode, sets unlimited width.\n"));
-	fprintf(fp, _("  -x            Enable HTML/XHTML output mode.\n"));
+	fprintf(fp, _("  -a             Enable alternative color mode.\n"));
+	fprintf(fp, _("  -b             Enable bold color mode.\n"));
+	fprintf(fp, _("  -c             Toggle color mode.\n"));
+	fprintf(fp, _("  -d             Set demo mode (no pausing).\n"));
+	fprintf(fp, _("  -e             Process expressions and commands on the command line.\n"));
+	fprintf(fp, _("  -h             Display this help and exit.\n"));
+	fprintf(fp, _("  -m number      Specify a memory size multiplier.\n"));
+	fprintf(fp, _("  -q             Set quiet mode (don't display prompts).\n"));
+	fprintf(fp, _("  -r             Disable readline or editline.\n"));
+	fprintf(fp, _("  -s level:time  Set enforced security level and max time for user's session.\n"));
+	fprintf(fp, _("  -t             Set test mode.  Use when comparing program output.\n"));
+	fprintf(fp, _("  -u             Set unbuffered output with input echo.\n"));
+	fprintf(fp, _("  -v             Display version number, then exit successfully.\n"));
+	fprintf(fp, _("  -w             Wide output mode, sets unlimited width.\n"));
+	fprintf(fp, _("  -x             Enable HTML/XHTML output mode.\n"));
 	fprintf(fp, _("\nPlease refer to the man page for details (type \"man mathomatic\" in shell).\n"));
 }
 
@@ -125,6 +125,7 @@ char	**argv;
 	double		new_size = 0;
 	int		aoption = false, coption = false, boption = false, wide_flag = false;
 	int		exit_value = 0;
+	unsigned int	time_out_seconds = 0;
 
 #if	WIN32_CONSOLE_COLORS
 	hOut = GetStdHandle(STD_OUTPUT_HANDLE);
@@ -150,15 +151,29 @@ char	**argv;
 	while ((i = getopt(argc, argv, "s:abqrtdchuvwxm:e")) >= 0) {
 		switch (i) {
 		case 's':
-#if	SECURE
-			fprintf(stderr, _("%s: Compiled for maximum security, therefore no need for setting security level.\n"), prog_name);
-#else
-			if (optarg)
+			if (optarg) {
 				security_level = strtod(optarg, &cp);
-			if (optarg == NULL || cp == NULL || cp == optarg || *cp) {
+#if	SECURE
+				if (security_level != 4) {
+					fprintf(stderr, _("%s: Already compiled for maximum security (level 4), therefore setting security level ignored.\n"), prog_name);
+				}
+#endif
+			}
+			if (optarg == NULL || cp == NULL || (cp == optarg && *cp != ':') || (*cp != '\0' && *cp != ':')) {
 				fprintf(stderr, _("%s: Error in setting security level.\n"), prog_name);
 				exit(2);
 			}
+			if (*cp == ':') {
+				time_out_seconds = strtol(cp + 1, &cp, 10);
+				if (!(*cp == '\0' && time_out_seconds > 0)) {
+					fprintf(stderr, _("%s: Error in setting time out seconds.\n"), prog_name);
+					exit(2);
+				}
+			}
+#if	!SECURE
+			if (time_out_seconds > 0) {
+				printf(_("Security level is %d, time out seconds is %d.\n"), security_level, time_out_seconds);
+			}
 #endif
 			break;
 		case 'w':
@@ -317,7 +332,7 @@ char	**argv;
 		if (eoption)
 			exit_value = 1;
 	} else {
-		if ((rv = set_signals())) {
+		if ((rv = set_signals(time_out_seconds))) {
 			fprintf(stderr, _("C signal handler setting failed!\n"));
 #if	DEBUG
 			fprintf(stderr, "Failing signal is \"%s\".\n", strsignal(rv));
@@ -407,7 +422,8 @@ main_io_loop(void)
  * Return zero on success, or a non-zero unsettable signal number on error.
  */
 int
-set_signals(void)
+set_signals(time_out_seconds)
+unsigned int	time_out_seconds;
 {
 	int	rv = 0;
 
@@ -417,7 +433,7 @@ set_signals(void)
 		rv = SIGINT;
 	if (signal(SIGTERM, exithandler) == SIG_ERR)
 		rv = SIGTERM;
-#if	!MINGW
+#if	0	/* Crashes entire shell window when readline is used and SIGHUP received. */
 	if (signal(SIGHUP, exithandler) == SIG_ERR)
 		rv = SIGHUP;
 #endif
@@ -425,10 +441,18 @@ set_signals(void)
 	if (signal(SIGWINCH, resizehandler) == SIG_ERR)
 		rv = SIGWINCH;
 #endif
-#if	TIMEOUT_SECONDS
+#if	0	/* Crashes entire shell when readline is used. */
 	if (signal(SIGALRM, alarmhandler) == SIG_ERR)
 		rv = SIGALRM;
-	alarm(TIMEOUT_SECONDS);
+#endif
+#if	!MINGW
+	if (time_out_seconds > 0) {
+		alarm(time_out_seconds);
+#if	TIMEOUT_SECONDS
+	} else {
+		alarm(TIMEOUT_SECONDS);
+#endif
+	}
 #endif
 	return rv;
 }
@@ -472,6 +496,7 @@ int	sig;
 	}
 }
 
+#if	0
 /*
  * Alarm signal handler.
  */
@@ -482,6 +507,7 @@ int	sig;
 	printf(_("\nTimeout, quitting...\n"));
 	exit_program(1);
 }
+#endif
 
 /*
  * Signal handler for proper exiting to the operating system.
