@@ -291,6 +291,7 @@ int		allow_space;	/* if false, any space characters terminate parsing */
 		case '\f':
 			if (allow_space)
 				continue;
+		case ',':
 		case '=':
 		case ';':
 		case '\0':
@@ -400,12 +401,13 @@ parse_power:
 		case '%':
 			if (operand) {
 #if	1
-/* Allow %e, %i, and %pi by ignoring % in the wrong place. */
-				operand = false;
-				break;
-#else
-				goto syntax_error;
+/* Allow Maxima's %e, %i, and %pi by ignoring % in the wrong place. */
+				if (isalpha(cp[1])) {
+					operand = false;
+					break;
+				}
 #endif
+				goto syntax_error;
 			}
 			equation[n].level = cur_level;
 			equation[n].kind = OPERATOR;
@@ -487,6 +489,7 @@ parse_power:
 				goto syntax_error;
 			}
 			cp++;
+			cp1 = NULL;
 			switch (*cp) {
 			case '+':
 			case '-':
@@ -497,11 +500,11 @@ parse_power:
 				i = strtol(cp, &cp1, 10) - 1;
 				break;
 			}
-			if (cp == cp1) {
+			if (cp1 == NULL || cp == cp1) {
 				put_up_arrow(cp - cp_start, _("Error parsing equation space number after #."));
 				return NULL;
 			}
-			if (i < 0 || i >= n_equations || n_lhs[i] <= 0) {
+			if (empty_equation_space(i)) {
 				put_up_arrow(cp - cp_start, _("No expression available in # specified equation space."));
 				return NULL;
 			}
@@ -555,7 +558,12 @@ parse_power:
 				}
 			}
 			if (*cp == '(') {
-				put_up_arrow(cp1 - cp_start, _("Named functions currently not implemented, except when using m4."));
+/* Named functions currently not implemented, except when using m4. */
+#if	LIBRARY
+				put_up_arrow(cp1 - cp_start, _("Unknown function."));
+#else
+				put_up_arrow(cp1 - cp_start, _("Unknown function; try using rmath, which allows basic functions."));
+#endif
 				return(NULL);
 			}
 			cp--;
