@@ -41,11 +41,12 @@ George Gesslein II, P.O. Box 224, Lansing, NY  14882-0224  USA.
 
 #ifndef	LDBL_DIG
 #define	USE_DOUBLES	1
+#warning "long doubles not supported by this C compiler."
 #endif
 
 #if	USE_DOUBLES
 typedef double double_type;
-#warning "Using only double floats instead of long double floats."
+#warning "Using only double floats instead of long double floats, as requested."
 #else
 typedef long double double_type;
 #endif
@@ -58,6 +59,11 @@ void	display_triangle(void);
 int	center_buf(int line_no, int cell_size);
 void	usage(int ev);
 
+#if	USE_DOUBLES
+int		precision = DBL_DIG;
+#else
+int		precision = LDBL_DIG;
+#endif
 int		glines = 26;
 int		gcell_size = 6;
 double_type	*garray[MAX_LINES];
@@ -163,9 +169,9 @@ display_triangle(void)
 		} else {
 			for (j = 0; j <= i; j++) {
 #if	USE_DOUBLES
-				printf("%.15g ", garray[i][j]);
+				printf("%.*g ", precision, garray[i][j]);
 #else
-				printf("%.18Lg ", garray[i][j]);
+				printf("%.*Lg ", precision, garray[i][j]);
 #endif
 			}
 		}
@@ -190,9 +196,9 @@ center_buf(int line_no, int cell_size)
 	gline_buf[0] = '\0';
 	for (j = 0; j <= line_no; j++) {
 #if	USE_DOUBLES
-		len = snprintf(buf2, sizeof(buf2), "%.15g", garray[line_no][j]);
+		len = snprintf(buf2, sizeof(buf2), "%.*g", precision, garray[line_no][j]);
 #else
-		len = snprintf(buf2, sizeof(buf2), "%.18Lg", garray[line_no][j]);
+		len = snprintf(buf2, sizeof(buf2), "%.*Lg", precision, garray[line_no][j]);
 #endif
 		assert(len > 0);
 		if (len >= cell_size) {
@@ -216,5 +222,6 @@ usage(int ev)
 	printf("Usage: %s [number-of-lines]\n\n", prog_name);
 	printf("Display up to %d lines of Pascal's triangle.\n", MAX_LINES);
 	printf("If number-of-lines is specified, don't center output.\n");
+	printf("Number of digits of precision is %d.\n", precision);
 	exit(ev);
 }
