@@ -183,7 +183,7 @@ main(int argc, char *argv[])
 			findsq(d1);
 		}
 	} else {
-		while (fgets(buf, sizeof(buf), stdin)) {
+		for (fflush(NULL); fgets(buf, sizeof(buf), stdin); fflush(NULL)) {
 			errno = 0;
 			d1 = strtol(buf, &cp, 10);
 			if (errno) {
