@@ -71,8 +71,6 @@ int sum_cmd(char *cp);
 int product_cmd(char *cp);
 int for_cmd(char *cp);
 int optimize_cmd(char *cp);
-int push_cmd(char *cp);
-int push_en(int en);
 int output_current_directory(FILE *ofp);
 int fprintf_escaped(FILE *ofp, char *cp);
 void output_options(FILE *ofp, int all_set_options);
@@ -202,10 +200,9 @@ int flist_equation(int n);
 void usage(FILE *fp);
 int main(int argc, char **argv);
 void main_io_loop(void);
-int set_signals(void);
+int set_signals(unsigned int time_out_seconds);
 void fphandler(int sig);
 void inthandler(int sig);
-void alarmhandler(int sig);
 void exithandler(int sig);
 void resizehandler(int sig);
 void exit_program(int exit_value);
