@@ -188,6 +188,7 @@ int		*np;		/* pointer to length of equation side */
 			longjmp(jmp_save, 13);
 		} else {
 			debug_level = decstrtol(cp, NULL);
+			printf(_("Debug level set to %d.\n"), debug_level);
 		}
 #else
 		longjmp(jmp_save, 13);
@@ -351,6 +352,9 @@ int		*np;		/* pointer to equation side length */
 /*
  * Factor out only the specified variable "v" and simplify a little.
  * Does not do any approximation.
+ *
+ * If v is IMAGINARY, simplify imaginary number division, so that the imaginary unit is
+ * not in the divisor.
  */
 void
 factorv(equation, np, v)
@@ -390,24 +394,22 @@ int		*np;
 
 /*
  * Approximate an equation side for the approximate command.
- *
- * Return true if something was approximated.
  */
-int
+void
 approximate(equation, np)
 token_type	*equation;
 int		*np;
 {
-	int	rv;
-
-	rv = subst_constants(equation, np);
-	approximate_roots = true;
-	simp_loop(equation, np);
-	if (factor_imaginary(equation, np)) {
-		rv = true;
+	if (repeat_flag) {
+		/* do more */
+		calc_simp(equation, np);
+	} else {
+		subst_constants(equation, np);
+		approximate_roots = true;
+		simp_loop(equation, np);
+		factor_imaginary(equation, np);
+		approximate_roots = false;
 	}
-	approximate_roots = false;
-	return rv;
 }
 
 /*
@@ -565,11 +567,7 @@ int		fc_level;	/* factor constants code, passed to factor_constants() */
 	long		v1, last_v;	/* Mathomatic variables */
 	sort_type	va[MAX_VARS];	/* array of all real variables found in equation side */
 
-#if	1
 	elim_loop(equation, np);
-#else
-	simp_loop(equation, np);
-#endif
 	if (uf_power_flag) {
 		uf_allpower(equation, np);
 	}
@@ -612,10 +610,16 @@ int		fc_level;	/* factor constants code, passed to factor_constants() */
 				simp2_divide(equation, np, 0L, fc_level);
 			}
 		}
-		/* make sure equation side is completely factored */
-		while (factor_plus(equation, np, MATCH_ANY, 0.0)) {
-			simp2_divide(equation, np, 0L, fc_level);
-		}
+	}
+#if	0	/* Messes up support/gcd.in and tests/quartic.in */
+	make_simple_fractions(equation, np);
+#endif
+	/* make sure equation side is completely factored */
+	while (factor_divide(equation, np, MATCH_ANY, 0.0)) {
+		simp2_divide(equation, np, MATCH_ANY, fc_level);
+	}
+	while (factor_plus(equation, np, MATCH_ANY, 0.0)) {
+		simp2_divide(equation, np, 0L, fc_level);
 	}
 	simp_ssub(equation, np, MATCH_ANY, 0.0, power_flag, true, fc_level);
 #if	0	/* Seems to complicate and change constants slightly when enabled. */
@@ -638,8 +642,11 @@ simple_frac_side(equation, np)
 token_type	*equation;	/* pointer to the beginning of equation side */
 int		*np;		/* pointer to length of equation side */
 {
-	if (*np <= 0)
+	if (*np == 1) {
+		make_simple_fractions(equation, np);
+		fractions_and_group(equation, np);
 		return;
+	}
 	simp_loop(equation, np);
 	poly_factor(equation, np, true);
 	do {
@@ -683,8 +690,11 @@ int		frac_flag;	/* "simplify fraction" option, simplify to the ratio of two poly
 	int		flag, poly_flag = true;
 	jmp_buf		save_save;
 
-	if (*np <= 1)	/* no need to simplify a single constant or variable */
+	if (*np == 1) {	/* no need to full simplify a single constant or variable */
+		make_simple_fractions(equation, np);
+		simpb_side(equation, np, true, !frac_flag, 2);
 		return;
+	}
 	debug_string(2, "Simplify input:");
 	side_debug(2, equation, *np);
 	simp_loop(equation, np);
@@ -817,7 +827,7 @@ int		frac_flag;	/* "simplify fraction" option, simplify to the ratio of two poly
 	uf_power(equation, np);
 	integer_root_simp(equation, np);
 	simpb_side(equation, np, true, true, 3);
-	poly_factor(equation, np, false);
+	poly_factor(equation, np, true);
 	simpb_side(equation, np, true, !frac_flag, 2);
 }
 
@@ -836,10 +846,10 @@ int		*np;		/* pointer to length of the equation side */
 int		quick_flag;	/* "simplify quick" option, simpler fractions with no (x+1)^2 expansion */
 int		frac_flag;	/* "simplify fraction" option, simplify to the ratio of two polynomials */
 {
-	if (*np <= 1)	/* no need to simplify a single constant or variable */
+	if (*np <= 0)
 		return;
 	simpa_side(equation, np, quick_flag, frac_flag);
-	if (repeat_flag) {
+	if (repeat_flag && *np > 1) {
 		do {
 			n_tes = *np;
 			blt(tes, equation, n_tes * sizeof(token_type));
@@ -1010,7 +1020,7 @@ token_type	*equation;
 int		*np;
 {
 	int	modified = false;
-	int	i, j, k;
+	int	i, j;
 	int	level;
 	double	d1, d2, numerator, denominator;
 
@@ -1035,21 +1045,23 @@ int		*np;
 				numerator = equation[i+1].token.constant;
 				if (numerator > 50.0 || numerator < 1.0 || fmod(numerator, 1.0) != 0.0)
 					continue;
+				denominator = equation[i+3].token.constant;
+				if (denominator > 50.0 || denominator < 2.0 || fmod(denominator, 1.0) != 0.0)
+					continue;
 				errno = 0;
 				d2 = pow(equation[i-1].token.constant, numerator);
 				if (errno) {
 					continue;
 				}
-				denominator = equation[i+3].token.constant;
-				if (denominator > 50.0 || denominator < 2.0 || fmod(denominator, 1.0) != 0.0)
-					continue;
 				if (!factor_one(d2))
 					continue;
 				d1 = 1.0;
 				for (j = 0; j < uno; j++) {
-					while (ucnt[j] >= denominator) {
-						d1 *= unique[j];
-						ucnt[j] -= denominator;
+					if (unique[j] > 0.0) {
+						while (ucnt[j] >= denominator) {
+							d1 *= unique[j];
+							ucnt[j] -= denominator;
+						}
 					}
 				}
 				if (d1 == 1.0)
@@ -1059,8 +1071,8 @@ int		*np;
 				}
 				equation[i+1].token.constant = 1.0;
 				equation[i-1].token.constant = multiply_out_unique();
-				for (k = i - 1; k < i + 4; k++) {
-					equation[k].level++;
+				for (j = i - 1; j < (i + 4); j++) {
+					equation[j].level++;
 				}
 				blt(&equation[i+1], &equation[i-1], (*np - (i - 1)) * sizeof(token_type));
 				*np += 2;
@@ -1246,7 +1258,9 @@ double	*k1p;	/* Pointer to operand 1 and where to store the result of the calcul
 int	op2;	/* Operator 2; always exists and comes immediately before operand 2, and usually after operand 1. */
 double	k2;	/* Operand 2; ignored for unary operators. */
 {
+#if	_REENTRANT
 	int	sign = 1;
+#endif
 	int	op1;
 	double	d, d1, d2;
 
@@ -1365,7 +1379,7 @@ double	k2;	/* Operand 2; ignored for unary operators. */
 			d *= d1;
 		}
 #else
-#if	_XOPEN_SOURCE >= 600 || _ISOC99_SOURCE || __USE_ISOC99 || MINGW
+#if	_XOPEN_SOURCE >= 600 || _ISOC99_SOURCE || __USE_ISOC99 || MINGW || __APPLE__ || USE_TGAMMA
 		/* Use true gamma for factorial if available, it is the nicest gamma() function. */
 		/* Problem is I don't know how to properly tell if it is available. */
 		d = tgamma(*k1p + 1.0);
@@ -1373,13 +1387,15 @@ double	k2;	/* Operand 2; ignored for unary operators. */
 			return false;
 		}
 #else
-#warning "Using lgamma_r(3); Not a problem, but tgamma(3) is more direct, if available."
-#if	0
+#if	!_REENTRANT
+#warning "Using lgamma(3); Not a problem, but tgamma(3) is more direct, if available."
 		d = exp(lgamma(*k1p + 1.0)) * signgam;
-#else	/* use reentrant version: */
+#else	/* use re-entrant version: */
+#warning "Using lgamma_r(3); Not a problem, but tgamma(3) is more direct, if available."
 		d = exp(lgamma_r(*k1p + 1.0, &sign));
 		d *= sign;
 #endif
+/* Just compile with -DUSE_TGAMMA, if tgamma(3) is available and not being used. */
 		if (errno) {	/* don't evaluate if overflow */
 			return false;
 		}
@@ -1845,23 +1861,33 @@ int		n2;		/* second sub-expression length */
 int		*diff_signp;	/* different sign flag pointer */
 {
 	int	l1, l2;
-
+	int	rv;
 #if	DEBUG
+	int	rv_should_be_false = false;
+
 	if (n1 < 1 || n2 < 1 || (n1 & 1) != 1 || (n2 & 1) != 1 || diff_signp == NULL || p1 == NULL || p2 == NULL) {
 		error_bug("Programming error in call to se_compare().");
 	}
 #endif
-#if	1
 	if (((n1 > n2) ? ((n1 + 1) / (n2 + 1)) : ((n2 + 1) / (n1 + 1))) > 3) {
 		/* expressions are grossly different in size, no need to compare, they are different */
+#if	DEBUG
+		rv_should_be_false = true;
+#else
 		*diff_signp = false;
 		return false;
-	}
 #endif
+	}
 	/* Find the proper ground levels of parentheses for the two sub-expressions: */
 	l1 = min_level(p1, n1);
 	l2 = min_level(p2, n2);
-	return compare_recurse(p1, n1, l1, p2, n2, l2, diff_signp);
+	rv = compare_recurse(p1, n1, l1, p2, n2, l2, diff_signp);
+#if	DEBUG
+	if (rv && rv_should_be_false) {
+		error_bug("Expression compare optimization failed in se_compare().");
+	}
+#endif
+	return rv;
 }
 
 /*
@@ -2115,7 +2141,7 @@ elim_sign(equation, np)
 token_type	*equation;
 int		*np;
 {
-	int		i, j;
+	int		i, j, k;
 	int		level;
 	int		modified = false;
 	int		op;
@@ -2129,9 +2155,20 @@ int		*np;
 		}
 #endif
 		level = equation[i].level;
-		if (equation[i].token.operatr == POWER
-		    && equation[i+1].level == level
-		    && equation[i+1].kind == CONSTANT) {
+		if (equation[i+1].kind == CONSTANT
+		    && equation[i].token.operatr == POWER
+		    && ((equation[i+1].level == level)
+		    || (equation[i+1].level == level + 1))) {
+			if (equation[i+1].level == level + 1) {
+				if (i + 3 >= *np || equation[i+2].token.operatr != TIMES)
+					continue;
+				for (k = i + 2; k < *np && equation[k].level >= (level + 1); k += 2)
+					;
+				if (k <= i + 2)
+					continue;
+				if (!is_integer_expr(&equation[i+3], k - (i + 3)))
+					continue;
+			}
 			f_to_fraction(equation[i+1].token.constant, &numerator, &denominator);
 			if (always_positive(numerator)) {
 				if (equation[i-1].level == level
@@ -2173,7 +2210,7 @@ int		*np;
 				}
 			} else {
 				if (equation[i-1].level == level && equation[i-1].kind == VARIABLE) {
-					if (equation[i-1].token.variable == IMAGINARY) {
+					if (equation[i-1].token.variable == IMAGINARY && equation[i+1].level == level) {
 						d = fmod(equation[i+1].token.constant, 4.0);
 						if (d == 1.0) {
 							equation[i].token.operatr = TIMES;
@@ -2396,7 +2433,9 @@ int		i1, i2;
 	n1 = e1 - i1;
 	n2 = e2 - i2;
 	blt(scratch, &equation[i1], (e2 - i1) * sizeof(token_type));
-	blt(&equation[i1+n2], &equation[e1], (i2 - e1) * sizeof(token_type));
+	if ((i1 + n2) != e1) {
+		blt(&equation[i1+n2], &equation[e1], (i2 - e1) * sizeof(token_type));
+	}
 	blt(&equation[i1], &scratch[i2-i1], n2 * sizeof(token_type));
 	blt(&equation[e2-n1], scratch, n1 * sizeof(token_type));
 }
